[PATCH 2 of 2 evolve-ext] evolvecmd: use modern vocabulary in help text for evolve

Anton Shestakov av6 at dwimlabs.net
Sun Oct 14 07:42:08 EDT 2018


# HG changeset patch
# User Anton Shestakov <av6 at dwimlabs.net>
# Date 1539517031 -7200
#      Sun Oct 14 13:37:11 2018 +0200
# Node ID fc9eb357bca259cab49e7665bc5ab72e26914e6f
# Parent  f3d9033c08be3b97861f490a62619887def287f8
evolvecmd: use modern vocabulary in help text for evolve

diff --git a/hgext3rd/evolve/evolvecmd.py b/hgext3rd/evolve/evolvecmd.py
--- a/hgext3rd/evolve/evolvecmd.py
+++ b/hgext3rd/evolve/evolvecmd.py
@@ -1362,20 +1362,20 @@ def evolve(ui, repo, **opts):
     """solve troubled changesets in your repository
 
     Modifying history can lead to various types of troubled changesets:
     unstable, bumped, or divergent. The evolve command resolves your troubles
     by executing one of the following actions:
 
     - update working copy to a successor
-    - rebase an unstable changeset
-    - extract the desired changes from a bumped changeset
-    - fuse divergent changesets back together
+    - rebase an orphan changeset
+    - extract the desired changes from a phase-divergent changeset
+    - fuse content-divergent changesets back together
 
     If you pass no arguments, evolve works in automatic mode: it will execute a
     single action to reduce instability related to your working copy. There are
     two cases for this action. First, if the parent of your working copy is
     obsolete, evolve updates to the parent's successor. Second, if the working
     copy parent is not obsolete but has obsolete predecessors, then evolve
     determines if there is an unstable changeset that can be rebased onto the
     working copy parent in order to reduce instability.
     If so, evolve rebases that changeset. If not, evolve refuses to guess your
     intention, and gives a hint about what you might want to do next.
@@ -1385,24 +1385,24 @@ def evolve(ui, repo, **opts):
     as well; this may change in future.)
 
     Automatic mode only handles common use cases. For example, it avoids taking
-    action in the case of ambiguity, and it ignores unstable changesets that
-    are not related to your working copy.
-    It also refuses to solve bumped or divergent changesets unless you
-    explicitly request such behavior (see below).
+    action in the case of ambiguity, and it ignores orphan changesets that are
+    not related to your working copy.
+    It also refuses to solve phase-divergent or content-divergent changesets
+    unless you explicitly request such behavior (see below).
 
     Eliminating all instability around your working copy may require multiple
     invocations of :hg:`evolve`. Alternately, use ``--all`` to recursively
     select and evolve all unstable changesets that can be rebased onto the
     working copy parent.
     This is more powerful than successive invocations, since ``--all`` handles
-    ambiguous cases (e.g. unstable changesets with multiple children) by
-    evolving all branches.
+    ambiguous cases (e.g. orphan changesets with multiple children) by evolving
+    all branches.
 
     When your repository cannot be handled by automatic mode, you might need to
     use ``--rev`` to specify a changeset to evolve. For example, if you have
     an unstable changeset that is not related to the working copy parent,
     you could use ``--rev`` to evolve it. Or, if some changeset has multiple
     unstable children, evolve in automatic mode refuses to guess which one to
     evolve; you have to use ``--rev`` in that case.
 
     Alternately, ``--any`` makes evolve search for the next evolvable changeset
@@ -1410,22 +1410,23 @@ def evolve(ui, repo, **opts):
 
     You can supply multiple revisions to evolve multiple troubled changesets
     in a single invocation. In revset terms, ``--any`` is equivalent to ``--rev
-    first(unstable())``. ``--rev`` and ``--all`` are mutually exclusive, as are
+    first(orphan())``. ``--rev`` and ``--all`` are mutually exclusive, as are
     ``--rev`` and ``--any``.
 
     ``hg evolve --any --all`` is useful for cleaning up instability across all
     branches, letting evolve figure out the appropriate order and destination.
 
-    When you have troubled changesets that are not unstable, :hg:`evolve`
-    refuses to consider them unless you specify the category of trouble you
-    wish to resolve, with ``--bumped`` or ``--divergent``. These options are
-    currently mutually exclusive with each other and with ``--unstable``
-    (the default). You can combine ``--bumped`` or ``--divergent`` with
-    ``--rev``, ``--all``, or ``--any``.
+    When you have troubled changesets that are not orphan, :hg:`evolve` refuses
+    to consider them unless you specify the category of trouble you
+    wish to resolve, with ``--phase-divergent`` or ``--content-divergent``.
+    These options are currently mutually exclusive with each other and with
+    ``--orphan`` (the default). You can combine ``--phase-divergent`` or
+    ``--content-divergent`` with ``--rev``, ``--all``, or ``--any``.
 
     You can also use the evolve command to list the troubles affecting your
     repository by using the --list flag. You can choose to display only some
-    categories of troubles with the --unstable, --divergent or --bumped flags.
+    categories of troubles with the --orphan, --content-divergent or
+    --phase-divergent flags.
 
     Interrupted
     ===========
@@ -1362,20 +1362,20 @@ def evolve(ui, repo, **opts):
 
     Modifying history can lead to various types of troubled changesets:
-    unstable, bumped, or divergent. The evolve command resolves your troubles
-    by executing one of the following actions:
+    orphan, phase-divergent, or content-divergent. The evolve command resolves
+    your troubles by executing one of the following actions:
 
     - update working copy to a successor
@@ -1362,20 +1362,20 @@ def evolve(ui, repo, **opts):
     obsolete, evolve updates to the parent's successor. Second, if the working
     copy parent is not obsolete but has obsolete predecessors, then evolve
-    determines if there is an unstable changeset that can be rebased onto the
+    determines if there is an orphan changeset that can be rebased onto the
     working copy parent in order to reduce instability.
     If so, evolve rebases that changeset. If not, evolve refuses to guess your
@@ -1385,24 +1385,24 @@ def evolve(ui, repo, **opts):
     Eliminating all instability around your working copy may require multiple
     invocations of :hg:`evolve`. Alternately, use ``--all`` to recursively
-    select and evolve all unstable changesets that can be rebased onto the
+    select and evolve all orphan changesets that can be rebased onto the
     working copy parent.
     This is more powerful than successive invocations, since ``--all`` handles
@@ -1385,24 +1385,24 @@ def evolve(ui, repo, **opts):
     When your repository cannot be handled by automatic mode, you might need to
     use ``--rev`` to specify a changeset to evolve. For example, if you have
-    an unstable changeset that is not related to the working copy parent,
+    an orphan changeset that is not related to the working copy parent,
     you could use ``--rev`` to evolve it. Or, if some changeset has multiple
@@ -1385,24 +1385,24 @@ def evolve(ui, repo, **opts):
     you could use ``--rev`` to evolve it. Or, if some changeset has multiple
-    unstable children, evolve in automatic mode refuses to guess which one to
+    orphan children, evolve in automatic mode refuses to guess which one to
     evolve; you have to use ``--rev`` in that case.
 


More information about the Mercurial-devel mailing list